/*
Widget Name:
- Expansion Panel

Description:
- An Expansion Panel holds its children.On click, it expands and collapses.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-expandablePanel.dart';
import 'custom-materialChip.dart';

Usage:
- Defining the callback and Expansion Panel objects

final List<ExpandablePanelData> paneldata = [];
    MaterialChipData chipdata = new MaterialChipData();
    onclickCardBtn(int nIndex, sText) {
      print(nIndex);
      print(sText);
    }
    ExpandablePanelData paneldataone =
    new ExpandablePanelData('Odisha', Icon(Icons.location_city), [
      CustomChipWidget(
        data: chipdata,
        callback: onclickCardBtn,
      ),
    ], ThemeData(accentColor: Colors.orange,unselectedWidgetColor: Colors.green),);
    ExpandablePanelData paneldatatwo =
    new ExpandablePanelData('Maharashtra', Icon(Icons.local_mall), <Widget>[
      ListTile(
        leading: Image.asset('images/card1.png'),
        title: Text('Test Title'),
        subtitle: Text('Test Title'),
        trailing: Image.asset('images/card1.png'),
      ),CustomChipWidget(
        data: chipdata,
        callback: onclickCardBtn,
      ),
    ], ThemeData(accentColor: Colors.red,unselectedWidgetColor: Colors.red));
    paneldata.add(paneldataone);
    paneldata.add(paneldatatwo);



- Widget call
      body: Container(
        child: expansionPanelWidget(paneldata),
      ),
Note:
Expansion Panel shouldn't be placed inside any widget, Other than body.

Author:
Satyabrat Padhy
*/
import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/theme.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

Widget expansionPanelWidget(List<ExpandablePanelData> data) {
  final ScrollController scrollController = ScrollController();

  return Container(
    child: ListView.builder(
      controller: scrollController,
      itemBuilder: (BuildContext context, int index) => entryItem(data[index]),
      itemCount: data.length,
    ),
  );
}

// Displays one Entry. If the entry has children then it's displayed
// with an ExpansionTile.
Widget entryItem(ExpandablePanelData root) {
  if (root.widget.isEmpty)
    return ListTile(
        title: Text(
      root.title,
      overflow: TextOverflow.ellipsis,
    ));
  return Card(
      child: Theme(
    data: root.themeData != null
        ? root.themeData
        : ThemeData(
            unselectedWidgetColor: mediumGreyThemeData().unselectedWidgetColor,
            accentColor: mediumGreyThemeData().highlightColor,
          ),
    child: ExpansionTile(
//      backgroundColor: mediumGreyThemeData().backgroundColor,
      key: PageStorageKey<ExpandablePanelData>(root),
      title: Text(
        root.title,
        overflow: TextOverflow.ellipsis,
      ),
      children: root.widget,
      leading: root.icon,
    ),
  ));
}
